netapp_ontap.models.volume_efficiency_idcs_scanner API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.volume_efficiency_idcs_scanner`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VolumeEfficiencyIdcsScannerSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VolumeEfficiencyIdcsScanner object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `enabled: bool GET`

    Specifies the administrative state of the inactive data compression scanner. Disabling inactive data compression is not allowed on Capacity optimized Flash with QAT supported platforms.

  `inactive_days: Size PATCH`

    Data blocks older than, or equal to, 'inactive_days' are picked up by the inactive data compression scanner. Valid for PATCH only. Only applicable when 'operation_state' set to 'active'.

  `mode: str GET POST PATCH`

    Specifies the mode of inactive data compression scanner. Valid for PATCH and GET.

    Valid choices:

    - default
    - compute_compression_savings
  `operation_state: str GET POST PATCH`

    Specifies the operational state of the inactive data compression scanner. VALID for PATCH and GET. Valid options for PATCH are "idle" and "active".

    Valid choices:

    - idle
    - active
  `status: str GET`

    Status of last inactive data compression scan on the volume.

    Valid choices:

    - success
    - failure
  `threshold_inactive_time: str GET`

    Time interval after which inactive data compression is automatically triggered. The value is in days and is represented in the ISO-8601 format "PD", for example "P3D" represents a duration of 3 days. This field is not supported on QAT supported platforms.

    Example: P14D